*  model NRZ transmitter with 3 taps
*  jitter added at 2 frequencies,  
*  one at half the baud rate and the other
*  at a lower frequency 
*  Parameters which can be passed are:
*
*  baud  =   the baud rate (bit rate for NRZ)
*  Apm   =   peak to peak differential amplitude into a perfect load
*  Trf   =   Rise and fall time in UI
*  pre   =   precursor tap weight,  total tap weight = 1.0
*  post  =   postcursor tap weight,  total tap weight = 1.0
*  TJ    =   total jitter peak to peak in UI
*  dutyCycle_over_TJ  = the fraction of jitter provided by half baud jitter
*
*  data in PRBS7_N.pwl  is a repeating 127 bit pattern with hooks for jitter
*  in each version N represents data advancement, so PRBS7_3.pwl dat is 
*  one bit time later than PRBS7_4 etc.

.subckt  Tx  Tx_T  Tx_C  GND \
  baud=10.3125g  Amp=1 Trf=.2  pre=.05  post=.25 \
  TJ=300m  dutyCycle_over_TJ=.2  

.param  period="1/baud"  tr="Trf*period" low="-.5*amp" hig=".5*amp"
.param  jt="period*TJ/2"  
.param  pj="dutyCycle_over_TJ*jt"  rj="jt-pj"  rjr=".098"
.param  main="1-abs(pre)-abs(post)"
*.param twopi="8*atan(1)"
.param  edge(n)="max(0,period*n+pj*cos(.5*twopi*n)+rj*sin(rjr*n*twopi))"

.include  "PRBS7_3.pwl"
.include  "PRBS7_4.pwl"
.include  "PRBS7_5.pwl"

G1   Tx_C   Tx_T  poly(2) PRBS7_5  0  init  0  0  0 0  0 "amp*pre/50"  0
G2   Tx_C   Tx_T  poly(2) PRBS7_4   0  init  0  0  0 0  0 "amp*main/50" 0
G3   Tx_C   Tx_T  poly(2) PRBS7_3 0  init  0  0  0 0  0 "amp*post/50" 0
vinit init  0   pwl(0  0  1p  1)

Rt   Tx_T   GND   50
Rc   Tx_C   GND   50

G1D   dummy  0     poly(2) PRBS7_5  0  init  0  0  0 0  0 "pre/100"  0
G2D   dummy  0     poly(2) PRBS7_4   0  init  0  0  0 0  0 "main/100" 0
G3D   dummy  0     poly(2) PRBS7_3 0  init  0  0  0 0  0 "post/100" 0
Rd    dummy  0    50

.ends Tx
